@@ -1,3 +1,16 @@
+use std::ops::Range;
+
+pub(crate) fn non_zero_range(p: &[f64]) -> Range<usize> {
+    let n = p.len();
+    let first_non_zero_index = p.iter().position(|&x| x != 0.0).unwrap_or(n);
+    let last_non_zero_index = n - p.iter().rev().position(|&x| x != 0.0).unwrap_or(0);
+    first_non_zero_index..last_non_zero_index
+}
+
+pub(crate) fn trim_zeros(p: &[f64]) -> &[f64] {
+    &p[non_zero_range(p)]
+}
+
 pub(crate) fn fast_pow(a: f64, b: f64) -> f64 {
     // works only if a is positive
     (a.log2() * b).exp2()
@@ -34,6 +47,12 @@ pub(crate) fn sum_negatives_positives(values: &[f64]) -> (f64, f64) {
     })
 }
 
+pub(crate) fn initial_guess(values: &[f64]) -> f64 {
+    let (outflows, inflows) = sum_negatives_positives(values);
+    let guess = inflows / -outflows - 1.0;
+    guess.clamp(-0.9, 0.1)
+}
+
 pub(crate) fn is_a_good_rate<F>(rate: f64, f: F) -> bool
 where
     F: Fn(f64) -> f64,
